#!/bin/sh
#
#	This file is executed by init(8) when the system is being
#	initialized for one of the "multi user" run levels (i.e.
#	levels 1 through 6).  
#
# /etc/rc.d/rc.M: 

## bootsplash
#. /etc/rc.d/rc.bootsplash

# Tell the viewers what's going to happen:
#progressbar 21
echo -en "\\033[1;33m"
echo "Going multiuser."
echo -en "\\033[1;37m"

# Remove stale dhcpcd network pid if system crash.
if [ -s /etc/dhcpc/dhcpcd-eth*.pid ]; then
#progressbar 22
/bin/rm /etc/dhcpc/dhcpcd-eth*.pid
fi

# Screen blanks after 0-60 minutes idle time.
# To turn speaker beep off: -bfreq 0
if [ -x /bin/setterm ]; then
#progressbar 23
/bin/setterm -blank 60 -powersave on
fi

# Look for a CD-ROM in a CD-ROM drive, if one is found
# mount it under /mnt/cdrom.
#if [ -x /etc/rc.d/rc.cdrom ]; then
#progressbar 24
#/etc/rc.d/rc.cdrom
#fi

# If there's no /etc/HOSTNAME, fall back on this default:
if [ ! -s /etc/HOSTNAME ]; then
#progressbar 25
echo "PnutOS" > /etc/HOSTNAME
fi

# Set the hostname from the /etc/HOSTNAME file. 
if [ -x /bin/hostname ]; then
#progressbar 26
/bin/hostname `cat /etc/HOSTNAME | cut -f1 -d .`
fi

if [ -x /usr/sbin/syslogd ]; then
echo "Starting system log daemon: syslogd: syslogd -m 0"
#progressbar 29
/usr/sbin/syslogd -m 0
echo "Starting kernel log daemon: klogd -2"
#progressbar 30
/usr/sbin/klogd -2
fi

# Start lpd daemon:
if [ -x /usr/sbin/lpd ]; then
echo "Starting printer daemon: lpd"
#progressbar 31
/usr/sbin/lpd
fi


# Start printer daemon:
if [ -x /usr/sbin/cupsd ]; then
echo "Starting printer daemon: cupsd"
#progressbar 33
MAKEDEV lp; /usr/sbin/cupsd
fi

# Start netatalk. (a file/print server for Macs using Appletalk)
#if [ -x /etc/rc.d/rc.atalk ]; then
#progressbar 34
#/etc/rc.d/rc.atalk
#fi

# Start crond (Dillon's crond):
# If you want cron to actually log activity to /var/adm/cron, then change
# -l10 to -l8 to increase the logging level.
if [ -x /usr/sbin/crond ]; then
echo "Starting cron daemon: crond -l8"
#progressbar 35
/usr/sbin/crond -l8 >>/var/adm/cron 2>&1
fi

# Start atd (manages jobs scheduled with 'at'):
if [ -x /usr/sbin/atd ]; then
echo "Starting at daemon: atd -b 15 -l 1"
#progressbar 36
/usr/sbin/atd -b 15 -l 1
fi

# Remove stale files (must be done after mount -a!)
#progressbar 37
/bin/rm -f /var/lock/LCK* /var/spool/uucp/LCK*
#progressbar 38
/bin/rm -rf 2>/dev/null /tmp/.* /tmp/* /var/tmp/.* /var/tmp/*

# Create /tmp directory if it doesn't exist.
if [ ! -d /tmp ]; then
#progressbar 39
mkdir /tmp
fi

# Ensure basic filesystem permissions sanity.
#progressbar 40
chmod 755 / 2>/dev/null
#progressbar 41
chmod 1777 /tmp /var/tmp 2>/dev/null

# Update all the shared library links automatically
#progressbar 42
/sbin/ldconfig

# Slackware-Mini-Quota-HOWTO:
# To really activate quotas, you'll need to add 'usrquota' to the appropriate
# partitions as listed in /etc/fstab.  Here's an example:
# /dev/hda2   /home   ext2   defaults,usrquota    1   1
# You'll then need to setup initial quota files at the top of the partitions
# to support quota, like this:
# touch /home/quota.user /home/quota.group
# chmod 600 /home/quota.user /home/quota.group
# Then, reboot to activate the system.
# To edit user quotas, use 'edquota'.  See 'man edquota'.  Also, the
# official Quota Mini-HOWTO has lots of useful information.  That can be found
# here:  ftp://ftp.cdrom.com/pub/linux/slackware/docs/mini/Quota

# Check quotas and then turn quota system on:
if grep -F quota /etc/fstab 1> /dev/null 2> /dev/null ; then
if [ -x /sbin/quotacheck ]; then
echo "Checking filesystem quotas"
#progressbar 43
/sbin/quotacheck -avug
fi
if [ -x /sbin/quotaon ]; then
echo "Activating filesystem quotas: quotacheck -avug"
#progressbar 44
/sbin/quotaon -avug
fi
fi

# Check for first time swap file and then turn it on system:
if [ -f /mnt/swap/swap.img.bz2 ]; then
echo "Starting a 128 Mb swap, e.g. see /mnt/swap/swap.txt"
#progressbar 45
/usr/bin/bunzip2 /mnt/swap/swap.img.bz2 1> /dev/null 2> /dev/null
fi

# Start the sendmail daemon:
if [ -x /usr/sbin/sendmail ]; then
echo "Starting sendmail daemon: sendmail -bd -q15m"
#progressbar 46
/usr/sbin/sendmail -bd -q15m
fi

# Start Xft2 font cache:
if [ -x /usr/X11R6/bin/fc-cache ]; then
echo "Starting Xorg/XFree86 font cache: /usr/X11R6/bin/fc-cache"
#progressbar 48
/usr/X11R6/bin/fc-cache
fi

# Start GNOME Fire starter - FireWall protection..
if [ -x /etc/firestarter/firewall.sh ]; then
echo "Starting FireWall/IPTables: /etc/firestarter/firewall.sh"
#progressbar 49
/etc/firestarter/firewall.sh
fi

# Typematic Rate:
if [ -x /sbin/kbdrate ]; then
echo "Starting Keyboard Console repeat rate: /sbin/kbdrate -r 30.0 -d 250"
#progressbar 50
/sbin/kbdrate -r 30.0 -d 250
fi

# Start 'XFS' True Type Font Server
if [ -x /usr/X11R6/bin/xfs ]; then
echo "Starting Xorg/XFree86 font daemon: xfs -config /etc/X11/fs/config -daemon"
#progressbar 51
/usr/X11R6/bin/xfs -config /etc/X11/fs/config -daemon
fi

# Start the DBUS Hardware daemon.
if [ -x /usr/bin/dbus-daemon-1 ]; then
echo "Starting DBUS daemon: dbus-daemon-1 --system"
#progressbar 52
/usr/bin/dbus-daemon-1 --system
fi

# Start the HAL Hardware daemon.
if [ -x /usr/sbin/hald ]; then
echo "Starting HAL daemon: hald --daemon=yes"
#progressbar 52
/usr/sbin/hald --daemon=yes
fi

# If there are SystemV init scripts for this runlevel, run them.
if [ -x /etc/rc.d/rc.sysvinit ]; then
echo "Starting SystemV init scripts: /etc/rc.d/rc.sysvinit"
#progressbar 53
/etc/rc.d/rc.sysvinit &>/dev/null
fi

# Initialize the NET subsystem.
if [ -x /etc/rc.d/rc.inet1 ]; then
echo "Initializing the NET1 subsystem: /etc/rc.d/rc.inet1"
#progressbar 58
/etc/rc.d/rc.inet1
fi

if [ -x /etc/rc.d/rc.inet2 ]; then
echo "Initializing the NET2 subsystem: /etc/rc.d/rc.inet2"
#progressbar 59
/etc/rc.d/rc.inet2
fi

# Start APM daemon 'apmd' for laptop computers.
if [ -f /proc/apm -a -x /usr/sbin/apmd ]; then
echo "Starting apm daemon: apmd"
#progressbar 60
/usr/sbin/apmd
fi

# Load a custom screen font if the user has an rc.font script.
if [ -x /etc/rc.d/rc.font ]; then
echo "Loading the custom screen console font: /etc/rc.d/rc.font"
#progressbar 61
/etc/rc.d/rc.font
fi

# Load a custom keymap if the user has an rc.keymap script.
if [ -x /etc/rc.d/rc.keymap ]; then
echo "Loading the custom keymapper: /etc/rc.d/rc.keymap"
#progressbar 62
/etc/rc.d/rc.keymap
fi

# iBCS Emulation for Linux
# The Intel Binary Compatibility Specification, or iBCS, specifies the
# interfaces between application programs and the surrounding operating
# system environment for i386 based systems. There are however several
# flavours of iBCS in use - SVR4, SVR3 plus several vendor specific
# extensions to SVR3 which are slightly different and incompatible. The
# iBCS emulator for Linux supports all flavours known so far.
if [ -x /etc/rc.d/rc.ibcs2 ]; then
#progressbar 63
/etc/rc.d/rc.ibcs2
fi

# Start the OpenSLP daemon:
if [ -x /usr/sbin/slpd ]; then
echo "Starting openslp daemon: slpd"
#progressbar 64
/usr/sbin/slpd
fi

# Start Samba (a file/print server for Win95/NT machines):
if [ -x /etc/rc.d/rc.samba ]; then
echo "Starting Samba file/print services: /etc/rc.d/rc.samba"
#progressbar 65
/etc/rc.d/rc.samba
fi

# Start GPM mouse driver.
# If you have a ps2 mouse put: -t ps2 -m /dev/mouse; Wheel mouse -t imps2.
#if [ -x /usr/bin/gpm ]; then
#echo "Starting mouse driver: gpm -t -m -r 30"
#progressbar 66
#/usr/bin/gpm -t ms -m /dev/mouse
#fi

# Start Lisa - OpenLDAP LAN.
if [ -x /opt/kde/bin/lisa ]; then
#progressbar 67
/opt/kde/bin/lisa &>/dev/null
fi

# Start SLAPD - OpenLDAP LAN: SEE /etc/openldap;
if [ -x /usr/bin/slapd  ]; then
#progressbar 70
/usr/bin/slapd &>/dev/null
fi

# Start the MLNET/FTP/HTTP Daemon(s). Telnet Daemon is started by /etc/inetd.conf.
# MLDonkey/MLNET is started by /etc/profile - non-root  :-)
if [ -x /home/xitami ]; then
echo "*************************************"
echo "*     T E L N E T - D A E M O N     *"
echo "*        F T P - D A E M O N        *"
echo "*       H T T P - D A E M O N       *"
echo "*   M L D O N K E Y - D A E M O N   *"
echo "*       L I S A - D A E M O N       *"
echo "*      S L A P D - D A E M O N      *"
echo "*        S S H - D A E M O N        *"
echo "*************************************"
cd /home
#progressbar 80
/home/xitami -s &>/dev/null
fi

# Start the local setup procedure.
if [ -x /etc/rc.d/rc.local ]; then
#progressbar 90
/etc/rc.d/rc.local
fi

# Starts the Linux logo. Try leaving this file as the last startup command.
if [ -x /usr/bin/ty2h9 ]; then
#progressbar 100
killall -9 -q -2 fbmngplay 2>/dev/null
/usr/bin/ty2h9 -c -yut "Welcome To The Pnut Project!"
fi

# All done.
